@@ -23,10 +23,7 @@ procman_gksu_create_root_password_dialog(char * command)
 
        gksu_context_set_command(context, command);
 
-       if (gksu_context_sudo_run_full(context,
-				      NULL, NULL,
-				      NULL, NULL,
-				      &error) == -1) {
+       if (gksu_context_sudo_run(context, &error) == -1) {
 	       g_warning("error: %s - command: '%s' - user: '%s'\n",
 			 error->message,
 			 gksu_context_get_command(context),
